==> nextcloud-29.0.12.tgz: nextcloud/apps/logreader/l10n/ca.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registre",
    "Errors in the log" : "Errors en el registre",
    "No errors in the logs since %s" : "No hi ha errors als registres des del dia %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n error als registres des del dia %s","%n errors als registres des del dia %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n advertència als registres des del dia %s","%n avisos als registres des del dia %s"],
    "Log Reader" : "Lector del registre",
    "A log reader for Nextcloud" : "Lector del registre per al Nextcloud",
    "Log reader for Nextcloud" : "Lector del registre per al Nextcloud",
    "Log reader" : "Lector del registre",
    "Open log reader settings" : "Obre els paràmetres del lector del registre",
    "Log reader settings" : "Paràmetres del lector del registre",
    "Currently the log file {file} is shown" : "Actualment, es mostra el fitxer de registre {file}",
    "Show server log" : "Mostra el registre del servidor",
    "Live view is disabled" : "La visualització en directe està inhabilitada",
    "No log file" : "No hi ha cap fitxer de registre",
    "File-based logging must be enabled to access logs from the Web UI." : "El registre basat en fitxers ha d'estar habilitat per accedir als registres des de la interfície d'usuari web.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Si creieu que es tracta d'un error, verifiqueu {setting} al vostre {config} i consulteu el Manual d'administració de Nextcloud.",
    "Level" : "Nivell",
    "App" : "Aplicació",
    "No app in context" : "Cap aplicació en context",
    "Time" : "Hora",
    "Copy raw entry" : "Copia l'entrada sense format",
    "Copy formatted entry" : "Copia l'entrada amb format",
    "Hide exception details" : "Amaga els detalls de l'excepció",
    "View exception details" : "Visualitza els detalls de l'excepció",
    "Raw log entry" : "Entrada del registre sense format",
    "Log entry successfully copied" : "L'entrada del registre s'ha copiat correctament",
    "Search log entries" : "Cerca entrades de registre",
    "Caused by {exception}" : "Causat per {exception}",
    "Line {line}" : "Línia {line}",
    "Filter log levels" : "Filtra per nivell de registre",
    "Set log level" : "Estableix el nivell de registre",
    "Time format" : "Format d'hora",
    "Live view" : "Visualització en directe",
    "Download/Upload logs" : "Baixada/pujada de registres",
    "Download logs" : "Baixa els registres",
    "Show local log file" : "Mostra el fitxer de registre local",
    "Upload local log file to be displayed" : "Pujada del fitxer de registre local que es mostrarà",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "No s'ha pogut analitzar el fitxer de registre local",
    "Raw data" : "Dades sense format",
    "Local time" : "Hora local",
    "UTC time" : "Hora UTC",
    "Relative" : "Relativa",
    "Time format used for displaying the timestamp" : "Format d'hora utilitzat per mostrar la marca de temps",
    "(Local log files only support the \"raw\" time format)" : "(Els fitxers de registre locals només admeten el format d'hora \"en brut\")",
    "Could not change date time format." : "No s'ha pogut canviar el format de data i hora.",
    "Polling is disabled because server is not configured to log to file" : "L'enquesta està desactivada perquè el servidor no està configurat per iniciar sessió al fitxer",
    "Polling (live view)" : "Enquesta (visualització en directe)",
    "Could not change live view setting." : "No s'ha pogut canviar el paràmetre de visualització en directe.",
    "Filter logging levels" : "Filtra per nivell de registre",
    "Could not set logging levels to show" : "No s'han pogut configurar els nivells de registre per mostrar",
    "Set backend loglevel" : "Estableix el nivell de registre del rerefons",
    "Could not set logging level" : "No s'ha pogut establir el nivell de registre",
    "Application" : "Aplicació",
    "Message" : "Missatge",
    "Log entry actions" : "Accions d'entrada de registre",
    "Loading older log entries" : "S'estan carregant entrades de registre més antigues",
    "No older log entries available" : "No hi ha entrades de registre més antigues disponibles",
    "Collapse row" : "Redueix la fila",
    "Expand row" : "Amplia la fila",
    "Show details" : "Mostra els detalls",
    "Debug" : "Depuració",
    "Info" : "Informació",
    "Warning" : "Avís",
    "Error" : "Error",
    "Fatal" : "Crític",
    "Could not load log entries" : "No s'han pogut carregar les entrades de registre",
    "Clipboard" : "Porta-retalls",
    "Could not fetch new log entries (server unavailable)" : "No s'han pogut obtenir entrades de registre noves (servidor no disponible)",
    "Could not fetch new entries" : "No s'han pogut obtenir entrades noves",
    "Could not copy to clipboard, please copy manually:" : "No s'ha pogut copiar al porta-retalls, copieu-lo manualment:",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} per {user} a les {time}\n"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/logreader/l10n/ca.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registre",
    "Errors in the log" : "Errors en el registre",
    "No errors in the logs since %s" : "No hi ha errors als registres des del dia %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n error als registres des del dia %s","%n errors als registres des del dia %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n advertència als registres des del dia %s","%n avisos als registres des del dia %s"],
    "Log Reader" : "Lector del registre",
    "A log reader for Nextcloud" : "Lector del registre per al Nextcloud",
    "Log reader for Nextcloud" : "Lector del registre per al Nextcloud",
    "Log reader" : "Lector del registre",
    "Open log reader settings" : "Obre els paràmetres del lector del registre",
    "Log reader settings" : "Paràmetres del lector del registre",
    "Currently the log file {file} is shown" : "Actualment, es mostra el fitxer de registre {file}",
    "Show server log" : "Mostra el registre del servidor",
    "Live view is disabled" : "La visualització en directe està inhabilitada",
    "No log file" : "No hi ha cap fitxer de registre",
    "File-based logging must be enabled to access logs from the Web UI." : "El registre basat en fitxers ha d'estar habilitat per accedir als registres des de la interfície d'usuari web.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Si creieu que es tracta d'un error, verifiqueu {setting} al vostre {config} i consulteu el Manual d'administració de Nextcloud.",
    "Level" : "Nivell",
    "App" : "Aplicació",
    "No app in context" : "Cap aplicació en context",
    "Time" : "Hora",
    "Copy raw entry" : "Copia l'entrada sense format",
    "Copy formatted entry" : "Copia l'entrada amb format",
    "Hide exception details" : "Amaga els detalls de l'excepció",
    "View exception details" : "Visualitza els detalls de l'excepció",
    "Raw log entry" : "Entrada del registre sense format",
    "Log entry successfully copied" : "L'entrada del registre s'ha copiat correctament",
    "Search log entries" : "Cerca entrades de registre",
    "Caused by {exception}" : "Causat per {exception}",
    "Line {line}" : "Línia {line}",
    "Filter log levels" : "Filtre els nivells de registre",
    "Set log level" : "Estableix el nivell de registre",
    "Time format" : "Format d'hora",
    "Live view" : "Visualització en directe",
    "Download/Upload logs" : "Baixada/pujada de registres",
    "Download logs" : "Baixa els registres",
    "Show local log file" : "Mostra el fitxer de registre local",
    "Upload local log file to be displayed" : "Pujada del fitxer de registre local que es mostrarà",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "No s'ha pogut analitzar el fitxer de registre local",
    "Raw data" : "Dades sense format",
    "Local time" : "Hora local",
    "UTC time" : "Hora UTC",
    "Relative" : "Relativa",
    "Time format used for displaying the timestamp" : "Format d'hora utilitzat per mostrar la marca de temps",
    "(Local log files only support the \"raw\" time format)" : "(Els fitxers de registre locals només admeten el format d'hora \"en brut\")",
    "Could not change date time format." : "No s'ha pogut canviar el format de data i hora.",
    "Polling is disabled because server is not configured to log to file" : "L'enquesta està desactivada perquè el servidor no està configurat per iniciar sessió al fitxer",
    "Polling (live view)" : "Enquesta (visualització en directe)",
    "Could not change live view setting." : "No s'ha pogut canviar el paràmetre de visualització en directe.",
    "Filter logging levels" : "Filtre els nivells de registre",
    "Could not set logging levels to show" : "No s'han pogut configurar els nivells de registre per mostrar",
    "Set backend loglevel" : "Estableix el nivell de registre del rerefons",
    "Could not set logging level" : "No s'ha pogut establir el nivell de registre",
    "Application" : "Aplicació",
    "Message" : "Missatge",
    "Log entry actions" : "Accions d'entrada de registre",
    "Loading older log entries" : "S'estan carregant entrades de registre més antigues",
    "No older log entries available" : "No hi ha entrades de registre més antigues disponibles",
    "Collapse row" : "Redueix la fila",
    "Expand row" : "Amplia la fila",
    "Show details" : "Mostra els detalls",
    "Debug" : "Depuració",
    "Info" : "Informació",
    "Warning" : "Avís",
    "Error" : "Error",
    "Fatal" : "Crític",
    "Could not load log entries" : "No s'han pogut carregar les entrades de registre",
    "Clipboard" : "Porta-retalls",
    "Could not fetch new log entries (server unavailable)" : "No s'han pogut obtenir entrades de registre noves (servidor no disponible)",
    "Could not fetch new entries" : "No s'han pogut obtenir entrades noves",
    "Could not copy to clipboard, please copy manually:" : "No s'ha pogut copiar al porta-retalls, copieu-lo manualment:",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} per {user} a les {time}\n",
    "line {line}" : "línia {line}",
    "Download / Upload logs" : "Baixada/pujada de registres"
},
"nplurals=2; plural=(n != 1);");
